@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: pngrotate.sh 369 2025-11-07 23:23:49Z leres $ (XSE)
+# @(#) $Id: pngrotate.sh 370 2025-12-28 23:40:38Z leres $ (XSE)
 #
 # pngrotate - rotate png images
 #
@@ -84,7 +84,7 @@ fi
 
 # Execute (or just echo if -n)
 execute() {
-	cmd="$*"
+	cmd="$@"
 	if [ ${dryrun} -eq 0 ]; then
 		eval "${cmd}"
 		return $?
@@ -187,7 +187,7 @@ while [ $# -gt 0 ]; do
 	fi
 
 	# Transform
-	t="${r%%.png}.$$.png"
+	t="`mktemp /tmp/${r}.XXXXXX`"
 	execute "ffmpeg -i ${f} ${flags} ${t}"
 	if [ $? -ne 0 ]; then
 		rm ${t}
