@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: util.c 345 2023-10-10 19:56:04Z leres $ (XSE)
+ * @(#) $Id: util.c 372 2026-01-10 18:15:28Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2002, 2006, 2008, 2009, 2010, 2015, 2023
+ * Copyright (c) 1999, 2000, 2001, 2002, 2006, 2008, 2009, 2010, 2015, 2023, 2026
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,6 @@ const char dotdot[] = "../";
 #define DOTDOT_LEN (sizeof(dotdot) - 1)
 const char *dot = dotdot + 1;
 #define DOT_LEN (DOTDOT_LEN - 1)
-char affix[2048];
 char prefix[2048];
 
 /*
@@ -201,19 +200,29 @@ matchfileordir(const char *name1, const char *name2, int isdir)
 
 /* pushd/pop that tracks the current prefix (if endp is not NULL) */
 int
-pushd(const char *dname, char **endp, int *dp)
+pushd(const char *dname, char **endpp, int *dp)
 {
 	const char *p;
+	char *end;
 
 	/* Remember end of the prefix string */
-	if (endp != NULL)
-		*endp = prefix + strlen(prefix);
+	if (endpp == NULL)
+		endpp = &end;
+	*endpp = prefix + strlen(prefix);
 
-	if (isdot(dname)) {
+	if (!isdot(dname)) {
+		/* Append current directory to prefix */
+		strlcat(prefix, dname, sizeof(prefix));
+
+		/* Now that we know it's a directory, insure trailing slash */
+		p = dname + strlen(dname) - 1;
+		if (p >= dname && *p != '/')
+			strlcat(prefix, "/", sizeof(prefix));
+	} else {
 		*dp = -1;
 		if (debug > 1)
-			fprintf(stderr, "%s: pushd noop \"%s%s\" (%d)\n",
-			    prog, affix, prefix, *dp);
+			fprintf(stderr, "%s: pushd noop \"%s\" (%d)\n",
+			    prog, prefix, *dp);
 		return (1);
 	}
 
@@ -221,35 +230,26 @@ pushd(const char *dname, char **endp, int *dp)
 	*dp = open(".", O_RDONLY);
 	if (*dp < 0) {
 		fprintf(stderr,
-		    "%s: pushd: open: Can't open directory %s%s: %s\n",
-		    prog, affix, prefix, strerror(errno));
+		    "%s: pushd: open: Can't open directory %s: %s\n",
+		    prog, prefix, strerror(errno));
 		++errors;
 		return (0);
 	}
 
 	/* Change directory */
 	if (chdir(dname) < 0) {
-		fprintf(stderr, "%s: pushd: chdir %s%s%s: %s\n",
-		    prog, affix, prefix, dname, strerror(errno));
+		fprintf(stderr, "%s: pushd: chdir %s%s: %s\n",
+		    prog, prefix, dname, strerror(errno));
 		(void)close(*dp);
 		*dp = -1;
+		**endpp = '\0';
 		++errors;
 		return (0);
 	}
 
-	if (endp != NULL) {
-		/* Appended current directory to prefix */
-		strlcat(prefix, dname, sizeof(prefix));
-
-		/* Now that we know it's a directory, insure trailing slash */
-		p = dname + strlen(dname) - 1;
-		if (p >= dname && *p != '/')
-			strlcat(prefix, "/", sizeof(prefix));
-	}
-
 	if (debug > 1)
-		fprintf(stderr, "%s: pushd \"%s%s\" (%d)\n",
-		    prog, affix, prefix, *dp);
+		fprintf(stderr, "%s: pushd \"%s\" (%d)\n",
+		    prog, prefix, *dp);
 	return (1);
 }
 
@@ -274,8 +274,8 @@ popd(char *endp, int d)
 		(void)close(d);
 	}
 	if (debug > 1)
-		fprintf(stderr, "%s: popd \"%s%s\" (%d)\n",
-		    prog, affix, prefix, d);
+		fprintf(stderr, "%s: popd \"%s\" (%d)\n",
+		    prog, prefix, d);
 	return (ret);
 }
 
