@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: webindex.c 367 2025-09-15 15:10:21Z leres $ (XSE)
+ * @(#) $Id: webindex.c 372 2026-01-10 18:15:28Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025
+ * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025, 2026
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -16,7 +16,7 @@
  */
 #ifndef lint
 static const char copyright[] =
-    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025\nCraig Leres\n";
+    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025, 2026\nCraig Leres\n";
 #endif
 
 #include <sys/types.h>
@@ -214,8 +214,7 @@ int
 main(int argc, char **argv)
 {
 	char *cp;
-	const char *p;
-	int i, d, op;
+	int i, op;
 	mode_t nmode, omode;
 
 	if ((cp = strrchr(argv[0], '/')) != NULL)
@@ -263,24 +262,10 @@ main(int argc, char **argv)
 	}
 
 	if (argc == optind) {
-		affix[0] = '\0';
 		(void)process(".");
 	} else {
-		for (i = optind; i < argc; ++i) {
-			if (isdot(argv[i]))
-				affix[0] = '\0';
-			else {
-				/* Insure trailing slash */
-				strlcpy(affix, argv[i], sizeof(affix));
-				p = affix + strlen(affix) - 1;
-				if (p >= affix && *p != '/')
-					strlcat(affix, "/", sizeof(affix));
-			}
-			if (pushd(argv[i], NULL, &d)) {
-				(void)process(".");
-				(void)popd(NULL, d);
-			}
-		}
+		for (i = optind; i < argc; ++i)
+			(void)process(argv[i]);
 	}
 
 	exit(errors != 0);
@@ -290,11 +275,11 @@ main(int argc, char **argv)
 size_t
 process(const char *dname)
 {
+	int i, d, row, col, force, intable, lastymd, ymd;
 	const char *p, *indexfn;
 	const char *table, *tr, *tail;
 	char *cp, *section, *prefixend;
 	char autosection;
-	int i, row, col, force, intable, lastymd, ymd;
 	struct timespec file_tim, ind_tim;
 	struct webfile *wp, *webfiles;
 	struct cf *cf;
@@ -303,7 +288,6 @@ process(const char *dname)
 	struct timespec mtim, ctim;
 	struct tm *tm;
 	char *otz;
-	int d, d2;
 	DIR *dirp;
 	FILE *f;
 	DIRENTRY *dp;
@@ -311,8 +295,8 @@ process(const char *dname)
 	char buf[128];
 
 	if (verbose > 1)
-		fprintf(stderr, "%s: processing %s%s%s\n",
-		    prog, affix, prefix, dname);
+		fprintf(stderr, "%s: processing %s%s\n",
+		    prog, prefix, dname);
 
 	/* Initialization */
 	dirp = NULL;
@@ -370,8 +354,8 @@ process(const char *dname)
 	/* Open the directory for scanning */
 	dirp = opendir(".");
 	if (dirp == NULL) {
-		fprintf(stderr, "%s: process: opendir %s: %s%s\n",
-		    prog, affix, prefix, strerror(errno));
+		fprintf(stderr, "%s: process: opendir %s: %s\n",
+		    prog, prefix, strerror(errno));
 		++errors;
 		goto bail;
 	}
@@ -379,8 +363,8 @@ process(const char *dname)
 	if (lstat(indexfn, &sbuf) < 0) {
 		/* OK if index.html doesn't exist */
 		if (errno != ENOENT) {
-			fprintf(stderr, "%s: process: lstat %s%s%s: %s\n",
-			    prog, affix, prefix, indexfn, strerror(errno));
+			fprintf(stderr, "%s: process: lstat %s%s: %s\n",
+			    prog, prefix, indexfn, strerror(errno));
 			++errors;
 			goto bail;
 		}
@@ -389,15 +373,15 @@ process(const char *dname)
 	} else {
 		/* If it doesn't look like we can update the index file, bail */
 		if ((sbuf.st_mode & S_IFMT) == S_IFLNK) {
-			fprintf(stderr, "%s: process: %s%s%s: is a symlink\n",
-			    prog, affix, prefix, indexfn);
+			fprintf(stderr, "%s: process: %s%s: is a symlink\n",
+			    prog, prefix, indexfn);
 			++errors;
 			goto bail;
 		}
 		if ((sbuf.st_mode & S_IFMT) != S_IFREG) {
 			fprintf(stderr,
-			    "%s: process: %s%s%s: not a regular file\n",
-			    prog, affix, prefix, indexfn);
+			    "%s: process: %s%s: not a regular file\n",
+			    prog, prefix, indexfn);
 			++errors;
 			goto bail;
 		}
@@ -409,8 +393,8 @@ process(const char *dname)
 		/* If index file wasn't created by us, don't update it */
 		f = fopen(indexfn, "r");
 		if (f == NULL) {
-			fprintf(stderr, "%s: process: fopen 1 %s%s%s: %s\n",
-			    prog, affix, prefix, indexfn, strerror(errno));
+			fprintf(stderr, "%s: process: fopen 1 %s%s: %s\n",
+			    prog, prefix, indexfn, strerror(errno));
 			++errors;
 			goto bail;
 		}
@@ -421,8 +405,8 @@ process(const char *dname)
 			reason = " (zero length)";
 		} else if (strstr(buf, magic) == NULL) {
 			fprintf(stderr,
-			    "%s: skipping %s%s%s (not created by %s)\n",
-			    prog, affix, prefix, indexfn, prog);
+			    "%s: skipping %s%s (not created by %s)\n",
+			    prog, prefix, indexfn, prog);
 			++errors;
 			goto bail;
 		}
@@ -456,8 +440,8 @@ process(const char *dname)
 			continue;
 
 		if (lstat(dp->d_name, &sbuf) < 0) {
-			fprintf(stderr, "%s: process: lstat %s%s%s: %s\n",
-			    prog, affix, prefix, dp->d_name, strerror(errno));
+			fprintf(stderr, "%s: process: lstat %s%s: %s\n",
+			    prog, prefix, dp->d_name, strerror(errno));
 			++errors;
 			/* XXX skip these */
 			continue;
@@ -470,8 +454,8 @@ process(const char *dname)
 			ctim = sbuf.st_mtim;
 			if (stat(dp->d_name, &sbuf) < 0) {
 				fprintf(stderr,
-				    "%s: process: stat %s%s%s: %s\n",
-				    prog, affix, prefix, dp->d_name,
+				    "%s: process: stat %s%s: %s\n",
+				    prog, prefix, dp->d_name,
 				    strerror(errno));
 				++errors;
 				/* XXX skip these */
@@ -523,12 +507,8 @@ process(const char *dname)
 				wp->w_type = T_DIR;
 				if (!WEBFILE_ISINVISIBLE(wp)) {
 					if (recurse) {
-						if (pushd(wp->w_name, NULL,
-						    &d2)) {
-							wp->w_nfiles =
-							    process(".");
-							(void)popd(NULL, d2);
-						}
+						wp->w_nfiles =
+						    process(wp->w_name);
 					} else {
 						wp->w_nfiles =
 						    countfiles(wp->w_name, cf);
@@ -615,15 +595,15 @@ process(const char *dname)
 	}
 
 	if (verbose)
-		fprintf(stderr, "%s: %s %s%s%s%s\n",
+		fprintf(stderr, "%s: %s %s%s%s\n",
 		    prog, ind_tim.tv_sec == 0 ? "creating" : "updating",
-		    affix, prefix, indexfn, reason);
+		    prefix, indexfn, reason);
 
 	/* Create directory if it doesn't exist */
 	if (access(naildir(cf), F_OK) < 0) {
 		if (verbose)
-			fprintf(stderr, "%s: creating %s%s%s/\n",
-			    prog, affix, prefix, naildir(cf));
+			fprintf(stderr, "%s: creating %s%s/\n",
+			    prog, prefix, naildir(cf));
 		if (mkdir(naildir(cf), 0777) < 0) {
 			fprintf(stderr, "%s: process: mkdir %s: %s\n",
 			    prog, naildir(cf), strerror(errno));
@@ -633,8 +613,8 @@ process(const char *dname)
 
 	f = fopen(indexfn, "w");
 	if (f == NULL) {
-		fprintf(stderr, "%s: process: fopen 2 %s%s%s: %s\n",
-		    prog, affix, prefix, indexfn, strerror(errno));
+		fprintf(stderr, "%s: process: fopen 2 %s%s: %s\n",
+		    prog, prefix, indexfn, strerror(errno));
 		++errors;
 		goto bail;
 	}
@@ -717,8 +697,8 @@ process(const char *dname)
 
 	/* Look for orphan sections */
 	for (sp = cf->c_section; sp != NULL; sp = sp->s_next)
-		fprintf(stderr, "%s: warning: %s%s%s: section not found\n",
-		    prog, affix, prefix, sp->s_file);
+		fprintf(stderr, "%s: warning: %s%s: section not found\n",
+		    prog, prefix, sp->s_file);
 
 	/* Look for orphan list elements */
 	reportunused(cf->c_alttext, "unused alttext");
@@ -752,8 +732,8 @@ bail:
 
 	/* Close the index file */
 	if (f != NULL && fclose(f) == EOF) {
-		fprintf(stderr, "%s: process: fclose %s%s%s: %s\n",
-		    prog, affix, prefix, indexfn, strerror(errno));
+		fprintf(stderr, "%s: process: fclose %s%s: %s\n",
+		    prog, prefix, indexfn, strerror(errno));
 		++errors;
 	}
 
@@ -835,10 +815,10 @@ processfile(FILE *f, struct webfile *wp, struct cf *cf,
 		} else {
 			/* Create/update the thumbnail image */
 			if (verbose)
-				fprintf(stderr, "%s: %s %s%s%s\n",
+				fprintf(stderr, "%s: %s %s%s\n",
 				    prog, wp2->w_tn_tim.tv_sec == 0 ?
 				    "creating" : "updating",
-				    affix, prefix, icon);
+				    prefix, icon);
 			if (createthumb(wp2, icon, cf)) {
 				w = wp2->w_tnw;
 				h = wp2->w_tnh;
@@ -966,8 +946,8 @@ processfile(FILE *f, struct webfile *wp, struct cf *cf,
 			(void)strftime(cp, sizeof(buf) - strlen(buf), p, tm);
 		} else if (wp->w_timestamp == 0 && cf->c_timestamps != NULL)
 			fprintf(stderr,
-			    "%s: warning: %s%s%s: missing timestamp\n",
-			    prog, affix, prefix, wp->w_name);
+			    "%s: warning: %s%s: missing timestamp\n",
+			    prog, prefix, wp->w_name);
 		cp = buf;
 		if (*cp != '\0')
 			fprintf(f, "%s<td><small>%s</small></td></tr>\n",
@@ -1190,8 +1170,8 @@ reapthumbnails(const char *dir, struct cf *cf,
 	if ((dirp = opendir(dir)) == NULL) {
 		if (errno != ENOENT) {
 			fprintf(stderr,
-			    "%s: reapthumbnails: opendir %s%s%s: %s\n",
-			    prog, affix, prefix, dir, strerror(errno));
+			    "%s: reapthumbnails: opendir %s%s: %s\n",
+			    prog, prefix, dir, strerror(errno));
 			++errors;
 		}
 		return (1);
@@ -1267,8 +1247,8 @@ reapthumbnails(const char *dir, struct cf *cf,
 		/* Ignore file (i.e. gripe but don't delete) */
 		if (ignorefile) {
 			fprintf(stderr,
-			    "%s: ignoring %s%s%s/%s (unknown file)\n",
-			    prog, affix, prefix, dir, dp->d_name);
+			    "%s: ignoring %s%s/%s (unknown file)\n",
+			    prog, prefix, dir, dp->d_name);
 			++force;
 			reason = " (ignore file)";
 			continue;
@@ -1277,12 +1257,12 @@ reapthumbnails(const char *dir, struct cf *cf,
 		/* Reap file */
 		sprintf(temp, "%s/%s", dir, dp->d_name);
 		if (verbose)
-			fprintf(stderr, "%s: deleting %s%s%s\n",
-			    prog, affix, prefix, temp);
+			fprintf(stderr, "%s: deleting %s%s\n",
+			    prog, prefix, temp);
 		if (unlink(temp) < 0)
 			fprintf(stderr,
-			    "%s: reapthumbnails: unlink %s%s%s: %s\n",
-			    prog, affix, prefix, temp, strerror(errno));
+			    "%s: reapthumbnails: unlink %s%s: %s\n",
+			    prog, prefix, temp, strerror(errno));
 		++force;
 		reason = " (reap file)";
 nextfile:
@@ -1467,7 +1447,7 @@ createthumb(struct webfile *wp, const char *fn, struct cf *cf)
 			fprintf(stderr,
 			    "%s: createthumb: \"%s ...\" failed: %s\n",
 			    prog, what, strerror(errno));
-		fprintf(stderr, "%s: deleting %s%s%s", prog, affix, prefix, fn);
+		fprintf(stderr, "%s: deleting %s%s", prog, prefix, fn);
 		if (remove(fn) < 0 && errno != ENOENT)
 			fprintf(stderr, " failed: %s", strerror(errno));
 		fprintf(stderr, "\n");
@@ -1478,13 +1458,13 @@ createthumb(struct webfile *wp, const char *fn, struct cf *cf)
 		wp->w_tnh = h;
 	} else {
 		fprintf(stderr,
-		    "%s: deleting %s%s%s (bad format thumbnail)\n",
-			prog, affix, prefix, fn);
+		    "%s: deleting %s%s (bad format thumbnail)\n",
+			prog, prefix, fn);
 			++errors;
 		errno = 0;
 		if (unlink(fn) < 0 && errno != ENOENT)
-			fprintf(stderr, "%s: createthumb: unlink %s%s%s: %s\n",
-			    prog, affix, prefix, fn, strerror(errno));
+			fprintf(stderr, "%s: createthumb: unlink %s%s: %s\n",
+			    prog, prefix, fn, strerror(errno));
 	}
 	return (1);
 }
@@ -1611,8 +1591,8 @@ checkmode(const char *fn, mode_t mode, int wtype)
 			cmode = 0111;
 	}
 	if ((mode & smode) != smode || (mode & cmode) != 0)
-		fprintf(stderr, "%s: warning: %s%s%s: bad permission (0%o)\n",
-		    prog, affix, prefix, fn, mode & 0777);
+		fprintf(stderr, "%s: warning: %s%s: bad permission (0%o)\n",
+		    prog, prefix, fn, mode & 0777);
 }
 
 int
